@@ -1,7 +1,7 @@
 ;;;; TYPEP und Verwandtes
 ;;;; Michael Stoll, 21. 10. 1988
 ;;;; Bruno Haible, 10.6.1989
-;;;; Sam Steingold 2000-2005
+;;;; Sam Steingold 2000-2005, 2007
 
 ;;; Datenstrukturen für TYPEP:
 ;;; - Ein Type-Specifier-Symbol hat auf seiner Propertyliste unter dem
@@ -256,16 +256,11 @@
          (eq (array-element-type x)
              #+BASE-CHAR=CHARACTER 'CHARACTER #-BASE-CHAR=CHARACTER 'BASE-CHAR
 ) ) )    )
-(def-atomic-type BIGNUM
-  (lambda (x) (and (integerp x) (not (fixnump x))))
-)
-(def-atomic-type BIT
-  (lambda (x) (or (eql x 0) (eql x 1)))
-)
+(def-atomic-type BIGNUM (lambda (x) (and (integerp x) (not (fixnump x)))))
+(def-atomic-type BIT (lambda (x) (or (eql x 0) (eql x 1))))
 (def-atomic-type BIT-VECTOR bit-vector-p)
-(def-atomic-type BOOLEAN
-  (lambda (x) (or (eq x 'nil) (eq x 't)))
-)
+(def-atomic-type BOOLEAN (lambda (x) (or (eq x 'nil) (eq x 't))))
+(def-atomic-type BYTE bytep)
 (def-atomic-type CHARACTER characterp)
 (def-atomic-type COMPILED-FUNCTION compiled-function-p)
 (def-atomic-type COMPLEX complexp)
@@ -343,7 +338,7 @@
 (def-atomic-type ffi::foreign-address
   (lambda (x) (eq 'ffi::foreign-address (type-of x))))
 ;; see lispbibl.d (#define FOREIGN) and predtype.d (TYPE-OF):
-#+(or unix ffi affi win32)
+#+(or unix ffi win32)
 (def-atomic-type foreign-pointer
   (lambda (x) (eq 'foreign-pointer (type-of x))))
 (def-atomic-type VECTOR vectorp)
@@ -404,7 +399,7 @@
                 (< (first low) x)
              )
              (t (error-of-type 'error
-                  (TEXT "~S: argument to ~S must be *, ~S or a list of ~S: ~S")
+                  #1=(TEXT "~S: argument to ~S must be *, ~S or a list of ~S: ~S")
                   'typep type type type low
        )     )  )
        (cond ((eq high '*))
@@ -413,8 +408,7 @@
                 (> (first high) x)
              )
              (t (error-of-type 'error
-                  (TEXT "~S: argument to ~S must be *, ~S or a list of ~S: ~S")
-                  'typep type type type high
+                  #1# 'typep type type type high
 ) )    )     )  )
 (defun c-typep-number (caller tester low high x)
   `(AND (,tester ,x)
@@ -423,7 +417,7 @@
                 ((and (consp low) (null (rest low)) (funcall tester (first low)))
                  `((< ,(first low) ,x))
                 )
-                (t (c-warn (TEXT "~S: argument to ~S must be *, ~S or a list of ~S: ~S")
+                (t (c-warn #1=(TEXT "~S: argument to ~S must be *, ~S or a list of ~S: ~S")
                            'typep caller caller caller low
                    )
                    (throw 'c-TYPEP nil)
@@ -433,9 +427,7 @@
                 ((and (consp high) (null (rest high)) (funcall tester (first high)))
                  `((> ,(first high) ,x))
                 )
-                (t (c-warn (TEXT "~S: argument to ~S must be *, ~S or a list of ~S: ~S")
-                           'typep caller caller caller high
-                   )
+                (t (c-warn #1# 'typep caller caller caller high)
                    (throw 'c-TYPEP nil)
           )     )
    )
@@ -531,9 +523,8 @@
 )
 (def-compound-type SIGNED-BYTE (&optional (n '*)) (x)
   (unless (or (eq n '*) (integerp n))
-    (error (TEXT "~S: argument to SIGNED-BYTE must be an integer or * : ~S")
-           'typep n
-  ) )
+    (error (TEXT "~S: argument to ~S must be an integer or * : ~S")
+           'typep 'signed-byte n))
   (and (integerp x) (or (eq n '*) (< (integer-length x) n)))
   `(AND (INTEGERP ,x)
         ,@(if (eq n '*) '() `((< (INTEGER-LENGTH ,x) ,n)))
@@ -541,9 +532,8 @@
 )
 (def-compound-type UNSIGNED-BYTE (&optional (n '*)) (x)
   (unless (or (eq n '*) (integerp n))
-    (error (TEXT "~S: argument to UNSIGNED-BYTE must be an integer or * : ~S")
-           'typep n
-  ) )
+    (error (TEXT "~S: argument to ~S must be an integer or * : ~S")
+           'typep 'unsigned-byte n))
   (and (integerp x)
        (not (minusp x))
        (or (eq n '*) (<= (integer-length x) n))
